"use strict";

var _ramda = require("ramda");

var _ramda2 = _interopRequireDefault(_ramda);

var _common = require("common");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var curry = null;
var all = null;

var isString = _ramda2.default.is(String);
var isArray = function isArray(type) {
	return _ramda2.default.type(type) === "Array";
};

var wrapper = {
	select: function select(cols) {
		var _type = _ramda2.default.type(cols);
		if (!cols || isArray(_type)) {
			console.error("cols must be Array, but got " + _type);
			return -1;
		}
		curry = _ramda2.default.project(cols);
		return this;
	},
	from: function from(table) {
		var _type = _ramda2.default.type(table);
		if (!table || isArray(_type)) {
			console.error("cols must be Array, but got " + _type);
			return -1;
		}
		if (_ramda2.default.type(curry) === "Null") {
			console.error("you must select first, then call the from method!");
			return -1;
		}
		all = curry(table);
		return this;
	},
	// only support string now
	sortBy: function sortBy(sortCol) {
		var _type = _ramda2.default.type(sortCol);
		if (!sortCol || _ramda2.default.either(isArray(_type) || isString(_type))) {
			console.error("sortCol must be Array or String, but got " + _type);
			return -1;
		}
		if (all === "Null") {
			console.error("you must select(...)from(...) first, then call the sortBy method!");
			return -1;
		}
		_ramda2.default.sortBy(_ramda2.default.compose(_ramda2.default.prop(sortCol)))(all);
		return this;
	},
	where: function where(conditions) {
		var pred = _ramda2.default.where({
			and: _ramda2.default.and,
			neq: _ramda2.default.complement(_ramda2.default.T()),
			gt: _ramda2.default.gt(_, 10),
			lt: _ramda2.default.lt(_, 20)
		});
	}
};
module.export = wrapper;
module.default = wrapper.select;